#!/usr/bin/perl

use strict;
use warnings;
use UI::Dialog::Backend::CDialog;
use VASM::Resource::Message;
use VASM::Resource::Action;

local $\ = "\n";

# Message files
my $CommonMessage = findMessageCatalog(qw/Common Message/);
my $UIMessage = findMessageCatalog(qw/Action UI Common Message/);
#my $CDialogMessage = findMessageCatalog(qw/Action UI CDialog Message/);
my $ErrorMessage = findErrorCatalog(qw/Action UI Common Error/);

# Dialog instance
my $dialog = UI::Dialog::Backend::CDialog->new(
  backtitle => $CommonMessage->Render(ID => 'VASM Title'),
  'ok-label' => $CommonMessage->Render(ID => 'OK'),
  'cancel-label' => $CommonMessage->Render(ID => 'Cancel'),
  'yes-label' => $CommonMessage->Render(ID => 'Yes'),
  'no-label' => $CommonMessage->Render(ID => 'No'),
  width => 75,
  height => 20,
  menuheight => 10
);

sub MainMenu {
  while (1) {
    ### Read
    my $choice = $dialog->menu(
      title => $UIMessage->Render(ID => 'Title'),
      text => $UIMessage->Render(ID => 'Main Menu Description'),
      list =>
        [ map 
            { $UIMessage->Render(ID => $_),
              $UIMessage->Render(ID => "$_ Description") }
              qw/File URI Template/ ]);

    ### Evaluate
    if ($dialog->state eq 'OK') {
      MediaMenu($choice);
    } elsif ($dialog->state eq 'CANCEL') {
      exit 0;
    }
  }
}

sub MediaMenu {
  my ($choice) = @_;
  my $directory = mediaDirectory($choice);

  while (1) {
    ### Read
    my @path = ($choice,
                split # For MIME types
                  m!/!,
                $dialog->menu(
                  title => $UIMessage->Render(ID => 'Title'),
                  text => $UIMessage->Render(ID => 'Media Menu Description'),
                  'extra-button' => 1,
                  'extra-label' => $CommonMessage->Render(ID => 'Back'),
                  list =>
                    [ map 
                        {
                          $_, $directory->Render(ID => $_) }
                          sort $directory->List ] ));

    ### Evaluate
    if ($dialog->state eq 'OK') {
      OperationMenu(@path);
    } elsif ($dialog->state eq 'EXTRA') {
      return;
    } elsif ($dialog->state eq 'CANCEL') {
      exit 0;
    }
  }
}

sub OperationMenu {
  my @path = @_;
  while (1) {
    ### Read
    my $operation =
      $dialog->menu(title => $UIMessage->Render(ID => 'Title'),
                    text => $UIMessage->Render(
                      ID => 'Operation Menu Description',
                      Arguments => [ join '/', @path[1..2] ]),
                    'extra-button' => 1,
                    'extra-label' => $CommonMessage->Render(ID => 'Back'),
                    list =>
                      [ map
                          { $UIMessage->Render(ID => "$_ Operation"),
                            $UIMessage->Render(
                              ID => "$_ Operation Description") }
                          qw/List Add Remove/ ] );
    ### Evaluate
    if ($dialog->state eq 'OK') {
      $dialog->msgbox(text => $operation);
      #OperationMenu(@path);
    } elsif ($dialog->state eq 'EXTRA') {
      return;
    } elsif ($dialog->state eq 'CANCEL') {
      exit 0;
    }
  }
}

# ### Main menu
# my $main = $dialog->menu(
#   title => $UIMessage->Render(ID => 'Title'),
#   text => $UIMessage->Render(ID => 'Main Menu Description'),
#   list => 
#     [ map {
#         $UIMessage->Render(ID => $_),
#         $UIMessage->Render(ID => "$_ Description")
#       }
#       qw/File URI Template/ ]);
# 
# if ($main eq 'File' or $main eq 'URI') { ### Media menu
#   my $directory = mediaDirectory($main);
#   my @path = ($main,
#               split # For MIME types
#                 m!/!,
#               $dialog->menu(
#                 title => $UIMessage->Render(ID => 'Title'),
#                 text => $UIMessage->Render(ID => 'Media Menu Description'),
#                 list => 
#                   [ map {
#                       $_, $directory->Render(ID => $_)
#                     } sort $directory->List ] ));
# 
#   ### Operations menu
#   my $operation =
#     $dialog->menu(title =>
#                     $UIMessage->Render(ID => 'Title'),
#                   text =>
#                     $UIMessage->Render(ID =>
#                                          'Operation Menu Description',
#                                        Arguments =>
#                                          [ join '/', @path[1..2] ]),
#                   list =>
#                     [ map {
#                         $UIMessage->Render(ID => "$_ Operation"),
#                         $UIMessage->Render(ID => "$_ Operation Description")
#                       } qw/List Add Remove/ ] );
#   my $catalog = findActionCatalog()
# 
#   if ($operation eq 'List') { ### List Operation
#     
#   } elsif ($operation eq 'Add') { ### Add Operation
#     
#   } elsif ($operation eq 'Remove') { ### Remove Operation
#     
#   }
# 
#   # Get list of media types and sort
#   # Offer to List, Add, Remove
# 
# } elsif ($main eq 'Template') { ### Template menu
#   # List templates
# }

MainMenu();
